@@ -49,16 +49,22 @@ INDIListener * INDIListener::_INDIListener = NULL;
 INDIListener * INDIListener::Instance()
 {
     if (_INDIListener == NULL)
-        _INDIListener = new INDIListener();
+        _INDIListener = new INDIListener(KStars::Instance());
 
     return _INDIListener;
 }
 
-INDIListener::INDIListener()
+INDIListener::INDIListener(QObject *parent) : QObject(parent)
 {
 
 }
 
+INDIListener::~INDIListener()
+{
+    qDeleteAll(devices);
+    qDeleteAll(st4Devices);
+}
+
 bool INDIListener::isStandardProperty(const QString &name)
 {
     for (int i=0; i < NINDI_STD; i++)
@@ -87,7 +93,7 @@ void INDIListener::addClient(ClientManager *cm)
 
     connect(cm, SIGNAL(newINDIDevice(DeviceInfo*)), this, SLOT(processDevice(DeviceInfo*)));
     connect(cm, SIGNAL(removeINDIDevice(DeviceInfo*)), this, SLOT(removeDevice(DeviceInfo*)), Qt::DirectConnection);
-    connect(cm, SIGNAL(newINDIProperty(INDI::Property*)), this, SLOT(registerProperty(INDI::Property*)));    
+    connect(cm, SIGNAL(newINDIProperty(INDI::Property*)), this, SLOT(registerProperty(INDI::Property*)));
     connect(cm, SIGNAL(removeINDIProperty(INDI::Property*)), this, SLOT(removeProperty(INDI::Property*)));
 
     connect(cm, SIGNAL(newINDISwitch(ISwitchVectorProperty*)), this, SLOT(processSwitch(ISwitchVectorProperty*)));
@@ -137,7 +143,7 @@ void INDIListener::processDevice(DeviceInfo *dv)
 }
 
 void INDIListener::removeDevice(DeviceInfo *dv)
-{        
+{
     if (Options::iNDILogging())
         qDebug() << "INDIListener: Removing device " << dv->getBaseDevice()->getDeviceName() << " with unique label " << dv->getDriverInfo()->getUniqueLabel();
 
@@ -210,8 +216,8 @@ void INDIListener::registerProperty(INDI::Property *prop)
                 {
                     devices.removeOne(gd);
                     gd = new ISD::Focuser(gd);
-                    devices.append(gd);                
-                }                
+                    devices.append(gd);
+                }
 
                emit newFocuser(gd);
             }
@@ -251,7 +257,6 @@ void INDIListener::registerProperty(INDI::Property *prop)
             }
             else if (!strcmp(prop->getName(), "FLAT_LIGHT_CONTROL"))
             {
-                #if (INDI_VERSION_MAJOR >= 1 && INDI_VERSION_MINOR >= 2)
                 // If light box part of dust cap
                 if (gd->getType() == KSTARS_UNKNOWN)
                 {
@@ -273,7 +278,6 @@ void INDIListener::registerProperty(INDI::Property *prop)
                         emit newLightBox(gd);
                     }
                 }
-                #endif
             }
 
             if (!strcmp(prop->getName(), "TELESCOPE_TIMED_GUIDE_WE"))
