@@ -11,6 +11,7 @@
 #include <errno.h>
 #include <sys/stat.h>
 
+#include <indidevapi.h>
 #include <indicom.h>
 
 #include <config-kstars.h>
@@ -18,7 +19,7 @@
 #include <QTcpSocket>
 #include <QTextEdit>
 
-#include <KProcess>
+#include <QProcess>
 #include <QLocale>
 #include <QDebug>
 #include <KMessageBox>
@@ -33,6 +34,7 @@
 #include "Options.h"
 #include "kstars.h"
 #include "kstarsdatetime.h"
+#include "kspaths.h"
 
 
 const int INDI_MAX_TRIES=3;
@@ -62,41 +64,67 @@ ServerManager::~ServerManager()
 }
 
 bool ServerManager::start()
-  {
+{
+#ifdef Q_OS_WIN
+    qWarning() << "INDI server is currently not supported on Windows.";
+    return false;
+#else
     bool connected=false;
     int fd=0;
-    serverProcess = new KProcess(this);
 
-    *serverProcess << Options::indiServer();
-    *serverProcess << "-v" << "-p" << port;
-    *serverProcess << "-m" << "100";
+    if (serverProcess == NULL){
+        serverProcess = new QProcess(this);
+        #ifdef Q_OS_OSX
+        QString driversDir=Options::indiDriversDir();
+        if(Options::indiDriversAreInternal())
+            driversDir=QCoreApplication::applicationDirPath()+"/indi";
+        QString indiServerDir=Options::indiServer();
+        if(Options::indiServerIsInternal())
+            indiServerDir=QCoreApplication::applicationDirPath()+"/indi";
+        else if(indiServerDir.length()>10)
+            indiServerDir=Options::indiServer().mid(0,Options::indiServer().length()-10);
+        QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+        env.insert("PATH", "/usr/local/bin:/usr/bin:" + driversDir + ":" + indiServerDir);
+        QString gscDirPath=KSPaths::writableLocation(QStandardPaths::GenericDataLocation) + "gsc";
+        env.insert("GSCDAT", gscDirPath);
+        serverProcess->setProcessEnvironment(env);
+        #endif
+    }
+
+    QStringList args;
+
+    args << "-v" << "-p" << port << "-m" << "100";
 
     QString fifoFile = QString("/tmp/indififo%1").arg(QUuid::createUuid().toString().mid(1, 8));
 
     if ( (fd = mkfifo (fifoFile.toLatin1(), S_IRUSR| S_IWUSR) < 0))
     {
-         KMessageBox::error(NULL, i18n("Error making FIFO file %1: %2.", fifoFile, strerror(errno)));
-         return false;
-   }
+        KMessageBox::error(NULL, i18n("Error making FIFO file %1: %2.", fifoFile, strerror(errno)));
+        return false;
+    }
 
     indiFIFO.setFileName(fifoFile);
 
     driverCrashed = false;
 
-   if (!indiFIFO.open(QIODevice::ReadWrite | QIODevice::Text))
-   {
-         qDebug() << "Unable to create INDI FIFO file: " << fifoFile << endl;
-         return false;
-   }
+    if (!indiFIFO.open(QIODevice::ReadWrite | QIODevice::Text))
+    {
+        qDebug() << "Unable to create INDI FIFO file: " << fifoFile << endl;
+        return false;
+    }
 
+    args << "-f" << fifoFile;    
 
-    *serverProcess << "-f" << fifoFile;
-
-    serverProcess->setOutputChannelMode(KProcess::SeparateChannels);
+    serverProcess->setProcessChannelMode(QProcess::SeparateChannels);
     serverProcess->setReadChannel(QProcess::StandardError);
 
+    #ifdef Q_OS_OSX
+    if(Options::indiServerIsInternal())
+        serverProcess->start(QCoreApplication::applicationDirPath()+"/indi/indiserver", args);
+    else
+    #endif
+        serverProcess->start(Options::indiServer(), args);
 
-    serverProcess->start();
 
     connected = serverProcess->waitForStarted();
 
@@ -107,11 +135,11 @@ bool ServerManager::start()
 
         emit started();
     }
+    else
+        KMessageBox::error(0, i18n("INDI server failed to start: %1", serverProcess->errorString()));
 
     return connected;
-
-
-
+#endif
 }
 
 bool ServerManager::startDriver(DriverInfo *dv)
@@ -142,22 +170,40 @@ bool ServerManager::startDriver(DriverInfo *dv)
 
     managedDrivers.append(dv);
     dv->setServerManager(this);
+    
+    QString driversDir=Options::indiDriversDir();
+    QString indiServerDir=Options::indiServer();
+
+
+     #ifdef Q_OS_OSX
+    if(Options::indiServerIsInternal())
+        driversDir=QCoreApplication::applicationDirPath()+"/indi";
+    if(Options::indiDriversAreInternal())
+        indiServerDir=QCoreApplication::applicationDirPath()+"/indi";
+    else if(indiServerDir.length()>10)
+        indiServerDir=Options::indiServer().mid(0,Options::indiServer().length()-10);
+    #endif
+
+    QStringList paths;
+    paths << "/usr/bin" << "/usr/local/bin" << driversDir << indiServerDir;
+
 
     if (QStandardPaths::findExecutable(dv->getDriver()).isEmpty())
     {
-         KMessageBox::error(NULL, i18n("Driver %1 was not found on the system. Please make sure the package that provides the '%1' binary is installed.", dv->getDriver()));
-         return false;
+        if(QStandardPaths::findExecutable(dv->getDriver(),paths).isEmpty()){
+            KMessageBox::error(NULL, i18n("Driver %1 was not found on the system. Please make sure the package that provides the '%1' binary is installed.", dv->getDriver()));
+            return false;
+        }
     }
 
-        //qDebug() << "Will run driver: " << dv->getName() << " with driver " << dv->getDriver() <<
-        //            " Unique Label " << dv->getUniqueLabel() << endl;
 
         out << "start " << dv->getDriver();
         if (dv->getUniqueLabel().isEmpty() == false)
             out << " -n \"" << dv->getUniqueLabel() << "\"";
         if (dv->getSkeletonFile().isEmpty() == false)
-            out << " -s \"" << Options::indiDriversDir() << "/" << dv->getSkeletonFile() << "\"";
+            out << " -s \"" << driversDir << QDir::separator() << dv->getSkeletonFile() << "\"";
         out << endl;
+
         out.flush();
 
         dv->setServerState(true);
@@ -246,7 +292,19 @@ void ServerManager::processServerError(QProcess::ProcessError err)
 
 void ServerManager::processStandardError()
 {
-    serverBuffer.append(serverProcess->readAllStandardError());
+    #ifdef Q_OS_WIN
+    qWarning() << "INDI server is currently not supported on Windows.";
+    return;
+    #else
+    QString stderr = serverProcess->readAllStandardError();
+
+    serverBuffer.append(stderr);
+
+    if (Options::iNDILogging())
+    {
+        foreach(QString msg, stderr.split("\n"))
+            qDebug() << "INDI Server: " << msg;
+    }
 
     if (driverCrashed == false && (serverBuffer.contains("stdin EOF") || serverBuffer.contains("stderr EOF")))
     {
@@ -264,6 +322,7 @@ void ServerManager::processStandardError()
    }
 
     emit newServerLog();
+    #endif
 }
 
 QString ServerManager::errorString()
