@@ -30,8 +30,8 @@
 #include <QDockWidget>
 #include <QPointer>
 #include <QInputDialog>
-//#include <QQuickWindow>
-//#include <QQuickView>
+#include <QQuickWindow>
+#include <QQuickView>
 #include <QDebug>
 #include <QAction>
 #include <QFileDialog>
@@ -80,9 +80,9 @@
 #include "tools/wutdialog.h"
 #include "tools/observinglist.h"
 #include "tools/eyepiecefield.h"
+#include "tools/adddeepskyobject.h"
 
-//FIXME Port to QML2
-#if 0
+#ifdef HAVE_KF5WIT
 #include "tools/whatsinteresting/wiview.h"
 #include "tools/whatsinteresting/wilpsettings.h"
 #include "tools/whatsinteresting/wiequipsettings.h"
@@ -238,18 +238,7 @@ void KStars::slotINDIToolBar()
 #ifdef HAVE_INDI
     KToggleAction *a = (KToggleAction*)sender();
 
-    if ( a == actionCollection()->action( "show_device_manager" ) )
-    {
-        if (a->isChecked())
-        {
-            DriverManager::Instance()->raise();
-            DriverManager::Instance()->activateWindow();
-            DriverManager::Instance()->showNormal();
-        }
-        else
-           DriverManager::Instance()->hide();
-    }    
-    else if ( a == actionCollection()->action( "show_control_panel" ) )
+    if ( a == actionCollection()->action( "show_control_panel" ) )
     {
        if (a->isChecked())
        {
@@ -412,9 +401,10 @@ void KStars::slotWUT() {
 }
 
 //FIXME Port to QML2
-#if 0
+//#if 0
 void KStars::slotWISettings()
 {
+#ifdef HAVE_KF5WIT
     if (m_WIView && !m_wiDock->isVisible())
     {
         slotShowWIView(1);
@@ -433,14 +423,16 @@ void KStars::slotWISettings()
     connect(dialog, SIGNAL(finished(int)), this, SLOT(slotShowWIView(int)));
 
     m_WISettings = new WILPSettings(this);
-    m_WIEquipmentSettings = new WIEquipSettings(this);
+    m_WIEquipmentSettings = new WIEquipSettings();
     dialog->addPage(m_WISettings, i18n("Light Pollution Settings"));
     dialog->addPage(m_WIEquipmentSettings, i18n("Equipment Settings - Equipment Type and Parameters"));
     dialog->show();
+#endif
 }
 
 void KStars::slotShowWIView(int status)
 {
+#ifdef HAVE_KF5WIT
 
     if (status == 0) return;          //Cancelled
 
@@ -452,13 +444,16 @@ void KStars::slotShowWIView(int status)
      * aperture of the equipment whichever available. However this is kept as a part of
      * the code as support to be utilised in the future.
      */
-    ObsConditions::Equipment equip = Options::noEquipCheck()
-    ? (ObsConditions::None) : (Options::telescopeCheck()
-    ? (Options::binocularsCheck() ? ObsConditions::Both : ObsConditions::Telescope)
-    : (Options::binocularsCheck() ? ObsConditions::Binoculars : ObsConditions::None));
+    ObsConditions::Equipment equip = ObsConditions::None;
 
-    ObsConditions::TelescopeType telType = (equip == ObsConditions::Telescope)
-                                           ? m_WIEquipmentSettings->getTelType() : ObsConditions::Invalid;
+    if (Options::telescopeCheck() && Options::binocularsCheck())
+        equip = ObsConditions::Both;
+    else if (Options::telescopeCheck())
+        equip = ObsConditions::Telescope;
+    else if (Options::binocularsCheck())
+        equip = ObsConditions::Binoculars;
+
+    ObsConditions::TelescopeType telType = (equip == ObsConditions::Telescope) ? m_WIEquipmentSettings->getTelType() : ObsConditions::Invalid;
 
     int aperture = m_WIEquipmentSettings->getAperture();
 
@@ -485,9 +480,9 @@ void KStars::slotShowWIView(int status)
         m_WIView->updateModels(m_ObsConditions);
         m_wiDock->setVisible(true);
     }
-}
 
 #endif
+}
 
 void KStars::slotCalendar() {
     if ( ! m_SkyCalendar ) m_SkyCalendar = new SkyCalendar(this);
@@ -533,11 +528,28 @@ void KStars::slotFlagManager() {
 void KStars::slotTelescopeWizard()
 {
 #ifdef HAVE_INDI
+    #ifndef Q_OS_WIN
+
+    QString indiServerDir=Options::indiServer();
+
+     #ifdef Q_OS_OSX
+    if(Options::indiServerIsInternal())
+        indiServerDir=QCoreApplication::applicationDirPath()+"/indi";
+    else if(indiServerDir.length()>10)
+        indiServerDir=Options::indiServer().mid(0,Options::indiServer().length()-10);
+    #endif
+
+    QStringList paths;
+    paths << "/usr/bin" << "/usr/local/bin" << indiServerDir;
+
     if (QStandardPaths::findExecutable("indiserver").isEmpty())
     {
-        KMessageBox::error(NULL, i18n("Unable to find INDI server. Please make sure the package that provides the 'indiserver' binary is installed."));
-        return;
+        if(QStandardPaths::findExecutable("indiserver",paths).isEmpty()){
+            KMessageBox::error(NULL, i18n("Unable to find INDI server. Please make sure the package that provides the 'indiserver' binary is installed."));
+            return;
+        }
     }
+    #endif
 
     QPointer<telescopeWizardProcess> twiz = new telescopeWizardProcess(this);
     twiz->exec();
@@ -548,11 +560,28 @@ void KStars::slotTelescopeWizard()
 void KStars::slotINDIPanel()
 {
 #ifdef HAVE_INDI
+    #ifndef Q_OS_WIN
+
+    QString indiServerDir=Options::indiServer();
+
+     #ifdef Q_OS_OSX
+    if(Options::indiServerIsInternal())
+        indiServerDir=QCoreApplication::applicationDirPath()+"/indi";
+    else if(indiServerDir.length()>10)
+        indiServerDir=Options::indiServer().mid(0,Options::indiServer().length()-10);
+    #endif
+
+    QStringList paths;
+    paths << "/usr/bin" << "/usr/local/bin" << indiServerDir;
+
     if (QStandardPaths::findExecutable("indiserver").isEmpty())
     {
-        KMessageBox::error(NULL, i18n("Unable to find INDI server. Please make sure the package that provides the 'indiserver' binary is installed."));
-        return;
+        if(QStandardPaths::findExecutable("indiserver",paths).isEmpty()){
+            KMessageBox::error(NULL, i18n("Unable to find INDI server. Please make sure the package that provides the 'indiserver' binary is installed."));
+            return;
+        }
     }
+    #endif
     GUIManager::Instance()->updateStatus();
 #endif
 }
@@ -560,11 +589,28 @@ void KStars::slotINDIPanel()
 void KStars::slotINDIDriver()
 {
 #ifdef HAVE_INDI
+    #ifndef Q_OS_WIN
+
+    QString indiServerDir=Options::indiServer();
+
+     #ifdef Q_OS_OSX
+    if(Options::indiServerIsInternal())
+        indiServerDir=QCoreApplication::applicationDirPath()+"/indi";
+    else if(indiServerDir.length()>10)
+        indiServerDir=Options::indiServer().mid(0,Options::indiServer().length()-10);
+    #endif
+
+    QStringList paths;
+    paths << "/usr/bin" << "/usr/local/bin" << indiServerDir;
+
     if (QStandardPaths::findExecutable("indiserver").isEmpty())
     {
-        KMessageBox::error(NULL, i18n("Unable to find INDI server. Please make sure the package that provides the 'indiserver' binary is installed."));
-        return;
+        if(QStandardPaths::findExecutable("indiserver",paths).isEmpty()){
+            KMessageBox::error(NULL, i18n("Unable to find INDI server. Please make sure the package that provides the 'indiserver' binary is installed."));
+            return;
+        }
     }
+    #endif
 
     DriverManager::Instance()->raise();
     DriverManager::Instance()->activateWindow();
@@ -578,11 +624,28 @@ void KStars::slotEkos()
 #ifdef HAVE_CFITSIO
 #ifdef HAVE_INDI
 
+    #ifndef Q_OS_WIN
+
+    QString indiServerDir=Options::indiServer();
+
+     #ifdef Q_OS_OSX
+    if(Options::indiServerIsInternal())
+        indiServerDir=QCoreApplication::applicationDirPath()+"/indi";
+    else if(indiServerDir.length()>10)
+        indiServerDir=Options::indiServer().mid(0,Options::indiServer().length()-10);
+    #endif
+
+    QStringList paths;
+    paths << "/usr/bin" << "/usr/local/bin" << indiServerDir;
+
     if (QStandardPaths::findExecutable("indiserver").isEmpty())
     {
-        KMessageBox::error(NULL, i18n("Unable to find INDI server. Please make sure the package that provides the 'indiserver' binary is installed."));
-        return;
+        if(QStandardPaths::findExecutable("indiserver",paths).isEmpty()){
+            KMessageBox::error(NULL, i18n("Unable to find INDI server. Please make sure the package that provides the 'indiserver' binary is installed."));
+            return;
+        }
     }
+    #endif
 
     ekosManager()->raise();
     ekosManager()->activateWindow();
@@ -639,6 +702,9 @@ void KStars::slotViewOps() {
     //KConfigDialog didn't find an instance of this dialog, so lets create it :
     KConfigDialog* dialog = new KConfigDialog( this, "settings",
                             Options::self() );
+    #ifdef Q_OS_OSX
+        dialog->setWindowFlags(Qt::Tool| Qt::WindowStaysOnTopHint);
+    #endif
 
     connect( dialog, SIGNAL( settingsChanged( const QString &) ), this, SLOT( slotApplyConfigChanges() ) );
 
@@ -650,20 +716,35 @@ void KStars::slotViewOps() {
     opcolors     = new OpsColors();
     opadvanced   = new OpsAdvanced();
 
-    dialog->addPage(opcatalog, i18n("Catalogs"), "kstars_catalog");
-    dialog->addPage(opsolsys, i18n("Solar System"), "kstars_solarsystem");
-    dialog->addPage(opssatellites, i18n("Satellites"), "kstars_satellites");
-    dialog->addPage(opssupernovae, i18n("Supernovae"), "kstars_supernovae");
-    dialog->addPage(opguides, i18n("Guides"), "kstars_guides");
-    dialog->addPage(opcolors, i18n("Colors"), "kstars_colors");
+    KPageWidgetItem *page;
+    
+    page = dialog->addPage(opcatalog, i18n("Catalogs"), "kstars_catalog");
+    page->setIcon(QIcon::fromTheme("kstars_catalog", QIcon(":/icons/breeze/default/kstars_catalog.svg")));
+                         
+    page = dialog->addPage(opsolsys, i18n("Solar System"), "kstars_solarsystem");
+    page->setIcon(QIcon::fromTheme("kstars_solarsystem", QIcon(":/icons/breeze/default/kstars_solarsystem.svg")));
+    
+    page = dialog->addPage(opssatellites, i18n("Satellites"), "kstars_satellites");
+    page->setIcon(QIcon::fromTheme("kstars_satellites", QIcon(":/icons/breeze/default/kstars_satellites.svg")));
+    
+    page = dialog->addPage(opssupernovae, i18n("Supernovae"), "kstars_supernovae");
+    page->setIcon(QIcon::fromTheme("kstars_supernovae", QIcon(":/icons/breeze/default/kstars_supernovae.svg")));
+    
+    page = dialog->addPage(opguides, i18n("Guides"), "kstars_guides");
+    page->setIcon(QIcon::fromTheme("kstars_guides", QIcon(":/icons/breeze/default/kstars_guides.svg")));
+    
+    page = dialog->addPage(opcolors, i18n("Colors"), "kstars_colors");
+    page->setIcon(QIcon::fromTheme("kstars_colors", QIcon(":/icons/breeze/default/kstars_colors.svg")));
 
     #ifdef HAVE_INDI
     opsindi = new OpsINDI();
-    dialog->addPage(opsindi, i18n("INDI"), "kstars_indi");
+    page= dialog->addPage(opsindi, i18n("INDI"), "kstars_indi");
+    page->setIcon(QIcon::fromTheme("kstars_indi", QIcon(":/icons/breeze/default/kstars_indi.svg")));
 
     #ifdef HAVE_CFITSIO
     opsekos = new OpsEkos();
     KPageWidgetItem *ekosOption = dialog->addPage(opsekos, i18n("Ekos"), "kstars_ekos");
+    ekosOption->setIcon(QIcon::fromTheme("kstars_ekos", QIcon(":/icons/breeze/default/kstars_ekos.svg")));
     if (m_EkosManager)
         m_EkosManager->setOptionsWidget(ekosOption);
     #endif
@@ -672,10 +753,12 @@ void KStars::slotViewOps() {
 
 #ifdef HAVE_XPLANET
     opsxplanet = new OpsXplanet( this );
-    dialog->addPage(opsxplanet, i18n("Xplanet"), "kstars_xplanet");
+    page = dialog->addPage(opsxplanet, i18n("Xplanet"), "kstars_xplanet");
+    page->setIcon(QIcon::fromTheme("kstars_xplanet", QIcon(":/icons/breeze/default/kstars_xplanet.svg")));
 #endif
 
-    dialog->addPage(opadvanced, i18n("Advanced"), "kstars_advanced");
+    page=dialog->addPage(opadvanced, i18n("Advanced"), "kstars_advanced");
+    page->setIcon(QIcon::fromTheme("kstars_advanced", QIcon(":/icons/breeze/default/kstars_advanced.svg")));
 
     dialog->show();
 }
@@ -762,7 +845,7 @@ void KStars::slotFind() {
 
     if ( !m_FindDialog ) qWarning() << i18n( "KStars::slotFind() - Not enough memory for dialog" ) ;
     SkyObject *targetObject;
-    if ( m_FindDialog->exec() == QDialog::Accepted && ( targetObject = m_FindDialog->selectedObject() ) ) {
+    if ( m_FindDialog->exec() == QDialog::Accepted && ( targetObject = m_FindDialog->targetObject() ) ) {
         map()->setClickedObject( targetObject );
         map()->setClickedPoint( map()->clickedObject() );
         map()->slotCenter();
@@ -777,16 +860,16 @@ void KStars::slotOpenFITS()
 {
 #ifdef HAVE_CFITSIO
 
-    static QUrl path;
+    static QUrl path = QUrl::fromLocalFile(QDir::homePath());
     QUrl fileURL = QFileDialog::getOpenFileUrl(KStars::Instance(), i18n("Open FITS"), path, "FITS (*.fits *.fit *.fts)");
 
     if (fileURL.isEmpty())
         return;
 
     // Remember last directory
-    path.setUrl(fileURL.path());
+    path.setUrl(fileURL.url(QUrl::RemoveFilename));
 
-    FITSViewer * fv = new FITSViewer(this);
+    FITSViewer * fv = new FITSViewer((Options::independentWindowFITS()) ? NULL : this);
     // Error opening file
     if (fv->addFITS(&fileURL, FITS_NORMAL, FITS_NONE, QString(), false) == -2)
         delete (fv);
@@ -809,7 +892,7 @@ void KStars::slotExportImage() {
     }
 
     //Warn user if file exists!
-    if (QFile::exists(fileURL.path()))
+    if (QFile::exists(fileURL.toLocalFile()))
     {
         int r=KMessageBox::warningContinueCancel(parentWidget(),
                 i18n( "A file named \"%1\" already exists. Overwrite it?" , fileURL.fileName()),
@@ -826,9 +909,9 @@ void KStars::slotExportImage() {
         //m_ImageExporter = new ImageExporter( this );
 
     if ( !m_ExportImageDialog ) {
-        m_ExportImageDialog = new ExportImageDialog( fileURL.url(), QSize( map()->width(), map()->height() ), KStarsData::Instance()->imageExporter() );
+        m_ExportImageDialog = new ExportImageDialog( fileURL.toLocalFile(), QSize( map()->width(), map()->height() ), KStarsData::Instance()->imageExporter() );
     } else {
-        m_ExportImageDialog->setOutputUrl( fileURL.url() );
+        m_ExportImageDialog->setOutputUrl( fileURL.toLocalFile() );
         m_ExportImageDialog->setOutputSize( QSize ( map()->width(), map()->height() ) );
     }
 
@@ -840,9 +923,18 @@ void KStars::slotRunScript() {
 
     QUrl fileURL = QFileDialog::getOpenFileUrl(KStars::Instance(), QString(), QUrl(QDir::homePath()), "*.kstars|" + i18nc("Filter by file type: KStars Scripts.", "KStars Scripts (*.kstars)") );
     QFile f;
-    QString fname;
+    //QString fname;
 
-    if ( fileURL.isValid() ) {
+    if ( fileURL.isValid() )
+    {
+
+        if (fileURL.isLocalFile() == false)
+        {
+            KMessageBox::sorry(0, i18n("Executing remote scripts is not supported."));
+            return;
+        }
+
+        /*
         if ( ! fileURL.isLocalFile() )
         {
             //Warn the user about executing remote code.
@@ -903,11 +995,13 @@ void KStars::slotRunScript() {
                 return;
             }
         }
+        */
 
         //Damn the torpedos and full speed ahead, we're executing the script!
         QTemporaryFile tmpfile;
         tmpfile.open();
 
+        /*
         if ( ! fileURL.isLocalFile() )
         {
             fname = tmpfile.fileName();
@@ -921,7 +1015,9 @@ void KStars::slotRunScript() {
             }
         } else {
             f.setFileName( fileURL.toLocalFile() );
-        }
+        }*/
+
+        f.setFileName( fileURL.toLocalFile() );
 
         if ( !f.open( QIODevice::ReadOnly) )
         {
@@ -1062,7 +1158,7 @@ void KStars::slotTrack() {
     if ( Options::isTracking() ) {
         Options::setIsTracking( false );
         actionCollection()->action("track_object")->setText( i18n( "Engage &Tracking" ) );
-        actionCollection()->action("track_object")->setIcon( QIcon::fromTheme("document-decrypt") );
+        actionCollection()->action("track_object")->setIcon( QIcon::fromTheme("document-decrypt", QIcon(":/icons/breeze/default/document-encrypt.svg")) );
 
         KSPlanetBase* planet = dynamic_cast<KSPlanetBase*>( map()->focusObject() );
         if( planet && data()->temporaryTrail ) {
@@ -1080,36 +1176,38 @@ void KStars::slotTrack() {
         map()->setFocusPoint( map()->clickedPoint() );
         Options::setIsTracking( true );
         actionCollection()->action("track_object")->setText( i18n( "Stop &Tracking" ) );
-        actionCollection()->action("track_object")->setIcon( QIcon::fromTheme("document-encrypt") );
+        actionCollection()->action("track_object")->setIcon( QIcon::fromTheme("document-encrypt", QIcon(":/icons/breeze/default/document-encrypt.svg")) );
     }
 
     map()->forceUpdate();
 }
 
 void KStars::slotManualFocus() {
-    QPointer<FocusDialog> focusDialog = new FocusDialog( this ); // = new FocusDialog( this );
+    QPointer<FocusDialog> focusDialog = new FocusDialog();
     if ( Options::useAltAz() ) focusDialog->activateAzAltPage();
 
-    if ( focusDialog->exec() == QDialog::Accepted ) {
-        //DEBUG
-        qDebug() << "focusDialog point: " << &focusDialog;
-
+    if ( focusDialog->exec() == QDialog::Accepted )
+    {
         //If the requested position is very near the pole, we need to point first
         //to an intermediate location just below the pole in order to get the longitudinal
         //position (RA/Az) right.
-        double realAlt( focusDialog->point().alt().Degrees() );
-        double realDec( focusDialog->point().dec().Degrees() );
-        if ( Options::useAltAz() && realAlt > 89.0 ) {
-            focusDialog->point().setAlt( 89.0 );
-            focusDialog->point().HorizontalToEquatorial( data()->lst(), data()->geo()->lat() );
+        double realAlt( focusDialog->point()->alt().Degrees() );
+        double realDec( focusDialog->point()->dec().Degrees() );
+        if ( Options::useAltAz() && realAlt > 89.0 )
+        {
+            focusDialog->point()->setAlt( 89.0 );
+            focusDialog->point()->HorizontalToEquatorial( data()->lst(), data()->geo()->lat() );
         }
-        if ( ! Options::useAltAz() && realDec > 89.0 ) {
-            focusDialog->point().setDec( 89.0 );
-            focusDialog->point().EquatorialToHorizontal( data()->lst(), data()->geo()->lat() );
+        if ( ! Options::useAltAz() && realDec > 89.0 )
+        {
+            focusDialog->point()->setDec( 89.0 );
+            focusDialog->point()->EquatorialToHorizontal( data()->lst(), data()->geo()->lat() );
         }
 
-        map()->setClickedPoint( & focusDialog->point() );
-        if ( Options::isTracking() ) slotTrack();
+        map()->setClickedPoint( focusDialog->point() );
+
+        if ( Options::isTracking() )
+            slotTrack();
 
         map()->slotCenter();
 
@@ -1121,15 +1219,20 @@ void KStars::slotManualFocus() {
         //Also, if the requested position was within 1 degree of the coordinate pole, this will
         //automatically correct the final pointing from the intermediate offset position to the final position
         data()->setSnapNextFocus();
-        if ( Options::useAltAz() ) {
-            map()->setDestinationAltAz( focusDialog->point().alt(), focusDialog->point().az() );
-        } else {
-            map()->setDestination( focusDialog->point().ra(), focusDialog->point().dec() );
+        if ( Options::useAltAz() )
+        {
+            map()->setDestinationAltAz( focusDialog->point()->alt(), focusDialog->point()->az() );
+        }
+        else
+        {
+            map()->setDestination( focusDialog->point()->ra(), focusDialog->point()->dec() );
         }
 
         //Now, if the requested point was near a pole, we need to reset the Alt/Dec of the focus.
-        if ( Options::useAltAz() && realAlt > 89.0 ) map()->focus()->setAlt( realAlt );
-        if ( ! Options::useAltAz() && realDec > 89.0 ) map()->focus()->setDec( realAlt );
+        if ( Options::useAltAz() && realAlt > 89.0 )
+            map()->focus()->setAlt( realAlt );
+        if ( ! Options::useAltAz() && realDec > 89.0 )
+            map()->focus()->setDec( realAlt );
 
         //Don't track if we set Alt/Az coordinates.  This way, Alt/Az remain constant.
         if ( focusDialog->usedAltAz() )
@@ -1200,20 +1303,20 @@ void KStars::slotCoordSys() {
 
 void KStars::slotMapProjection() {
     if ( sender() == actionCollection()->action("project_lambert") )
-        Options::setProjection( SkyMap::Lambert );
+        Options::setProjection( Projector::Lambert );
     if ( sender() == actionCollection()->action("project_azequidistant") )
-        Options::setProjection( SkyMap::AzimuthalEquidistant );
+        Options::setProjection( Projector::AzimuthalEquidistant );
     if ( sender() == actionCollection()->action("project_orthographic") )
-        Options::setProjection( SkyMap::Orthographic );
+        Options::setProjection( Projector::Orthographic );
     if ( sender() == actionCollection()->action("project_equirectangular") )
-        Options::setProjection( SkyMap::Equirectangular );
+        Options::setProjection( Projector::Equirectangular );
     if ( sender() == actionCollection()->action("project_stereographic") )
-        Options::setProjection( SkyMap::Stereographic );
+        Options::setProjection( Projector::Stereographic );
     if ( sender() == actionCollection()->action("project_gnomonic") )
-        Options::setProjection( SkyMap::Gnomonic );
+        Options::setProjection( Projector::Gnomonic );
 
     //DEBUG
-    qDebug() << i18n( "Projection system: %1", Options::projection() );
+    qDebug() << "Projection system: " << Options::projection();
 
     m_SkyMap->forceUpdate();
 }
@@ -1248,8 +1351,9 @@ void KStars::slotTargetSymbol(bool flag) {
 
 void KStars::slotFOVEdit() {
     QPointer<FOVDialog> fovdlg = new FOVDialog( this );
-    if ( fovdlg->exec() == QDialog::Accepted ) {
-        fovdlg->writeFOVList();
+    if ( fovdlg->exec() == QDialog::Accepted )
+    {
+        FOVManager::save();
         repopulateFOV();
     }
     delete fovdlg;
@@ -1292,7 +1396,7 @@ void KStars::slotEyepieceView( SkyPoint *sp, const QString &imagePath ) {
     const FOV *fov = 0;
     if( !data()->getAvailableFOVs().isEmpty() ) {
         // Ask the user to choose from a list of available FOVs.
-        int index;
+        //int index;
         const FOV *f;
         QMap< QString, const FOV * > nameToFovMap;
         foreach( f, data()->getAvailableFOVs() ) {
@@ -1411,6 +1515,18 @@ void KStars::slotAboutToQuit()
     //synch the config file with the Config object
     writeConfig();
 
+    //Terminate Child Processes if on OS X
+#ifdef Q_OS_OSX
+    QProcess* quit = new QProcess(this);
+    quit->start("killall kdeinit5");
+    quit->waitForFinished(1000);
+    quit->start("killall klauncher");
+    quit->waitForFinished(1000);
+    quit->start("killall kioslave");
+    quit->waitForFinished(1000);
+    delete quit;
+#endif
+
 }
 
 void KStars::slotShowPositionBar(SkyPoint* p )
@@ -1463,3 +1579,11 @@ void KStars::slotUpdateSatellites()
 {
     data()->skyComposite()->satellites()->updateTLEs();
 }
+
+void KStars::slotAddDeepSkyObject() {
+    if( ! m_addDSODialog ) {
+        Q_ASSERT( data() && data()->skyComposite() && data()->skyComposite()->manualAdditionsComponent() );
+        m_addDSODialog = new AddDeepSkyObject( this, data()->skyComposite()->manualAdditionsComponent() );
+    }
+    m_addDSODialog->show();
+}
