@@ -21,11 +21,13 @@
 #include <QLabel>
 #include <QCheckBox>
 #include <QRadioButton>
+#include <QDesktopServices>
 
 #include "Options.h"
 #include "kstars.h"
 #include "ksutils.h"
 #include "widgets/timestepbox.h"
+#include "kspaths.h"
 
 OpsAdvanced::OpsAdvanced()
         : QFrame(KStars::Instance())
@@ -46,6 +48,15 @@ OpsAdvanced::OpsAdvanced()
     connect (kcfg_VerboseLogging, SIGNAL(toggled(bool)), this, SLOT(slotToggleVerbosityOptions()));
 
     connect(kcfg_LogToFile, SIGNAL(toggled(bool)), this, SLOT(slotToggleOutputOptions()));
+
+    connect(showLogsB, SIGNAL(clicked()), this, SLOT(slotShowLogFiles()));
+
+    connect( kcfg_ObsListDemoteHole, &QCheckBox::toggled, [this]( bool state ) {
+            kcfg_ObsListHoleSize->setEnabled( state );
+        } );
+
+    foreach(QAbstractButton *b, modulesGroup->buttons())
+        b->setEnabled(kcfg_VerboseLogging->isChecked());
 }
 
 OpsAdvanced::~OpsAdvanced() {}
@@ -64,26 +75,30 @@ void OpsAdvanced::slotToggleVerbosityOptions()
 {
     if (kcfg_DisableLogging->isChecked())
         KSUtils::Logging::Disable();
+
+    foreach(QAbstractButton *b, modulesGroup->buttons())
+    {
+        b->setEnabled(kcfg_VerboseLogging->isChecked());
+        // If verbose is not checked, CLEAR all selections
+        b->setChecked(kcfg_VerboseLogging->isChecked() ? b->isChecked() : false);
+    }
 }
 
 void OpsAdvanced::slotToggleOutputOptions()
 {
     if (kcfg_LogToDefault->isChecked())
     {
-        kcfg_VerboseLogFile->setEnabled(false);
 
         if (kcfg_DisableLogging->isChecked() == false)
             KSUtils::Logging::UseDefault();
     }
     else
-    {
-        kcfg_VerboseLogFile->setEnabled(true);
-
-        if (kcfg_VerboseLogFile->text().isEmpty())
-            kcfg_VerboseLogFile->setText(QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + "kstars.log");
-
-        if (kcfg_DisableLogging->isChecked() == false)
-            KSUtils::Logging::UseFile(kcfg_VerboseLogFile->text());
-    }
+            KSUtils::Logging::UseFile();
 }
 
+void OpsAdvanced::slotShowLogFiles()
+{
+    QUrl path = QUrl::fromLocalFile(KSPaths::writableLocation(QStandardPaths::GenericDataLocation) + "logs");
+
+    QDesktopServices::openUrl(path);
+}
