@@ -28,7 +28,7 @@
 #include <kcolorscheme.h>
 #include <kglobal.h>
 #include <kglobalsettings.h>
-#include <kdebug.h>
+#include <QDebug>
 #include <kcalendarsystem.h>
 
 #include <QActionEvent>
@@ -37,6 +37,8 @@
 #include <QtGui/QStyleOptionViewItem>
 
 #include <cmath>
+#include <KLocale>
+#include <QFontDatabase>
 
 MoonPhaseCalendar::MoonPhaseCalendar( KSMoon &moon, KSSun &sun, QWidget *parent ) :
     KDateTable(parent),
@@ -60,7 +62,7 @@ QSize MoonPhaseCalendar::sizeHint() const {
 
 void MoonPhaseCalendar::loadImages() {
     computeMoonImageSize();
-    kDebug() << "Loading moon images. MoonImageSize = " << MoonImageSize;
+    qDebug() << "Loading moon images. MoonImageSize = " << MoonImageSize;
     for( int i = 0; i < 36; ++i ) {
         QString imName = QString().sprintf("moon%02d", i);
         m_Images[i] =
@@ -73,7 +75,7 @@ void MoonPhaseCalendar::loadImages() {
 void MoonPhaseCalendar::computeMoonImageSize() {
     cellWidth  = width() / ( double ) numDayColumns;
     cellHeight = height() / ( double ) numWeekRows;
-    kDebug() << cellWidth << cellHeight;
+    qDebug() << cellWidth << cellHeight;
     MoonImageSize = ( (cellWidth > cellHeight - 12) ? cellHeight - 12 : cellWidth ) - 2; // FIXME: Using hard-coded fontsize
 }
 
@@ -120,7 +122,7 @@ void MoonPhaseCalendar::paintCell( QPainter *painter, int row, int col, const KC
     QString cellText;
     QPen pen;
     QColor cellBackgroundColor, cellTextColor;
-    QFont cellFont = KGlobalSettings::generalFont();
+    QFont cellFont = QFontDatabase::systemFont(QFontDatabase::GeneralFont);
     bool workingDay = false;
     int cellWeekDay, pos;
 
@@ -134,12 +136,12 @@ void MoonPhaseCalendar::paintCell( QPainter *painter, int row, int col, const KC
     }
 
     //See if cell day is normally a working day
-    if ( KGlobal::locale()->workingWeekStartDay() <= KGlobal::locale()->workingWeekEndDay() ) {
-        workingDay = cellWeekDay >= KGlobal::locale()->workingWeekStartDay()
-                  && cellWeekDay <= KGlobal::locale()->workingWeekEndDay();
+    if ( KLocale::global()->workingWeekStartDay() <= KLocale::global()->workingWeekEndDay() ) {
+        workingDay = cellWeekDay >= KLocale::global()->workingWeekStartDay()
+                  && cellWeekDay <= KLocale::global()->workingWeekEndDay();
     } else {
-        workingDay = cellWeekDay >= KGlobal::locale()->workingWeekStartDay()
-                  || cellWeekDay <= KGlobal::locale()->workingWeekEndDay();
+        workingDay = cellWeekDay >= KLocale::global()->workingWeekStartDay()
+                  || cellWeekDay <= KLocale::global()->workingWeekEndDay();
     }
 
     if( row == 0 ) {
@@ -203,7 +205,7 @@ void MoonPhaseCalendar::paintCell( QPainter *painter, int row, int col, const KC
             //Determine various characteristics of the cell date
             bool selectedDay = ( cellDate == date() );
             bool currentDay = ( cellDate == QDate::currentDate() );
-            bool dayOfPray = ( calendar()->dayOfWeek( cellDate ) == KGlobal::locale()->weekDayOfPray() );
+            bool dayOfPray = ( calendar()->dayOfWeek( cellDate ) == KLocale::global()->weekDayOfPray() );
 
             //Default values for a normal cell
             cellBackgroundColor = palette().color( backgroundRole() );
@@ -267,7 +269,7 @@ void MoonPhaseCalendar::paintCell( QPainter *painter, int row, int col, const KC
                                  // 12 + (( drawRect.height() - 12 ) - MoonImageSize)/2,
                                  // m_Images[ iPhase ] );
             // FIXME: Using hard coded fontsize
-            //            kDebug() << "Drew moon image " << iPhase;
+            //            qDebug() << "Drew moon image " << iPhase;
         }
     }
 
